Module: Vident

Defined in:
lib/vident.rb,
lib/vident/error.rb,
lib/vident/types.rb,
lib/vident/engine.rb,
lib/vident/caching.rb,
lib/vident/version.rb,
lib/vident/tailwind.rb,
lib/vident/component.rb,
lib/vident/stable_id.rb,
lib/vident/internals/dsl.rb,
lib/vident/stimulus/base.rb,
lib/vident/stimulus/null.rb,
lib/vident/stimulus_null.rb,
lib/vident/internals/plan.rb,
lib/vident/stimulus/param.rb,
lib/vident/stimulus/value.rb,
lib/vident/internals/draft.rb,
lib/vident/stimulus/action.rb,
lib/vident/stimulus/naming.rb,
lib/vident/stimulus/outlet.rb,
lib/vident/stimulus/target.rb,
lib/vident/stimulus/selector.rb,
lib/vident/internals/registry.rb,
lib/vident/internals/resolver.rb,
lib/vident/stimulus/class_map.rb,
lib/vident/stimulus/collection.rb,
lib/vident/stimulus/combinable.rb,
lib/vident/stimulus/controller.rb,
lib/vident/capabilities/caching.rb,
lib/vident/capabilities/tailwind.rb,
lib/vident/internals/declaration.rb,
lib/vident/internals/declarations.rb,
lib/vident/capabilities/declarable.rb,
lib/vident/capabilities/inspectable.rb,
lib/vident/internals/action_builder.rb,
lib/vident/internals/target_builder.rb,
lib/vident/capabilities/identifiable.rb,
lib/vident/internals/attribute_writer.rb,
lib/vident/capabilities/stimulus_draft.rb,
lib/vident/internals/class_list_builder.rb,
lib/vident/capabilities/stimulus_parsing.rb,
lib/vident/capabilities/stimulus_mutation.rb,
lib/vident/capabilities/stimulus_declaring.rb,
lib/vident/capabilities/class_list_building.rb,
lib/vident/capabilities/root_element_rendering.rb,
lib/vident/capabilities/stimulus_data_emitting.rb,
lib/generators/vident/install/install_generator.rb,
lib/vident/capabilities/child_element_rendering.rb,
lib/vident/capabilities/stimulus_attribute_strings.rb,
lib/generators/vident/component/component_generator.rb

Defined Under Namespace

Modules: Capabilities, Component, Generators, Internals, Stimulus, Types Classes: ConfigurationError, DeclarationError, Engine, Error, ParseError, RenderError, StableId, StateError

Constant Summary collapse

Caching =

Top-level alias for the mixin at ‘Vident::Capabilities::Caching`.

Capabilities::Caching
VERSION =
"3.0.0"
Tailwind =

Top-level alias for the mixin at ‘Vident::Capabilities::Tailwind`.

Capabilities::Tailwind
StimulusNull =

Sentinel: emits the literal string “null” as the data attribute value. For Stimulus ‘Object` and `Array` value types this is JSON-parsed to JS `null`; other value types will read it as garbage (“null” string / NaN / truthy), so only use this with nullable Object/Array values.

A bare ‘nil` (static or returned from a proc) omits the attribute entirely so Stimulus uses its per-type default. Reach for this sentinel only when you need an explicit JS `null`.

Object.new.tap do |s|
  def s.inspect = "Vident::StimulusNull"

  def s.to_s = "null"
end.freeze

Class Method Summary collapse

Class Method Details

.Selector(css) ⇒ Object



12
# File 'lib/vident/stimulus/selector.rb', line 12

def self.Selector(css) = Stimulus::Selector.new(css: css)